[![Linters](https://github.com/dmitriyVasilievich1986/passwords_access/actions/workflows/lint.yml/badge.svg)](https://github.com/dmitriyVasilievich1986/passwords_access/actions/workflows/lint.yml)
[![linting: pylint](https://img.shields.io/badge/linting-pylint-yellowgreen)](https://github.com/pylint-dev/pylint)
